@@ -18,7 +18,14 @@ class DebianNetworkManager(NetworkManager):
 
     @classmethod
     def __verify__(cls):
-        """Same behaviour for Debian and Ubuntu < 18"""
+        """
+        Verify if this manager is relevant. Use the same manager for Debian
+        and Ubuntu < 18.
+
+        :return: bool
+        :rtype: bool
+        """
+
         check_prior_ubuntu = False
         if 'Ubuntu' in aj.platform_string:
             ubuntu_version = int(aj.platform_string[7:9])
@@ -29,6 +36,13 @@ class DebianNetworkManager(NetworkManager):
         NetworkManager.__init__(self, context)
 
     def get_augeas(self):
+        """
+        Read the content of /etc/network/interfaces through augeas.
+
+        :return: Augeas object
+        :rtype: augeas
+        """
+
         aug = Augeas(modules=[{
             'name': 'Interfaces',
             'lens': 'Interfaces.lns',
@@ -41,6 +55,13 @@ class DebianNetworkManager(NetworkManager):
         return aug
 
     def get_config(self):
+        """
+        Parse the content of /etc/network/interface through augeas.
+
+        :return: List of iface informations, one iface per dict
+        :rtype: list of dict
+        """
+
         aug = self.get_augeas()
         ifaces = []
         for path in aug.match(self.aug_path + '/iface[*]'):
@@ -67,6 +88,13 @@ class DebianNetworkManager(NetworkManager):
         return ifaces
 
     def set_config(self, config):
+        """
+        Set the new config in the config file through augeas.
+
+        :param config: List of iface informations, one dict per iface
+        :type config: list of dict
+        """
+
         aug = self.get_augeas()
         for index, iface in enumerate(config):
             path = self.aug_path + ('/iface[%i]' % (index + 1))
@@ -89,21 +117,58 @@ class DebianNetworkManager(NetworkManager):
         aug.save()
 
     def get_state(self, iface):
+        """
+        Get ip and status for an iface.
+
+        :param iface: Network interface, e.g. eth0
+        :type iface: string
+        :return: Ip and status
+        :rtype: dict
+        """
+
         return {
             'address': ifconfig_get_ip(iface),
             'up': ifconfig_get_up(iface),
         }
 
     def up(self, iface):
+        """
+        Bring an iface up.
+
+        :param iface: Network interface, e.g. eth0
+        :type iface: string
+        """
+
         ifconfig_up(iface)
 
     def down(self, iface):
+        """
+        Bring an iface down.
+
+        :param iface: Network interface, e.g. eth0
+        :type iface: string
+        """
+
         ifconfig_down(iface)
 
     def get_hostname(self):
+        """
+        Get hostname value.
+
+        :return: Hostname
+        :rtype: string
+        """
+
         return subprocess.check_output('hostname', encoding='utf-8')
 
     def set_hostname(self, value):
+        """
+        Write new hostname in /etc/hostname.
+
+        :param value: Hostname name
+        :type value: string
+        """
+
         with open('/etc/hostname', 'w') as f:
             f.write(value)
         subprocess.check_call(['hostname', value])
